@@ -1,5 +1,5 @@
 /**
- * Isotope v1.5.08
+ * Isotope v1.5.10
  * An exquisite jQuery plugin for magical layouts
  * http://isotope.metafizzy.co
  *
@@ -388,9 +388,10 @@
       this.reloadItems();
       
       // get top left position of where the bricks should be
-      var $cursor = $( document.createElement('div') ).prependTo( this.element );
-      this.offset = $cursor.position();
-      $cursor.remove();
+      this.offset = {
+        left: parseInt( this.element.css('padding-left'), 10 ),
+        top: parseInt( this.element.css('padding-top'), 10 )
+      };
 
       // add isotope class first time around
       var instance = this;
@@ -623,6 +624,7 @@
             this.isUsingJQueryAnimation ? 'animate' : 'css'
           ),
           animOpts = this.options.animationOptions,
+          onLayout = this.options.onLayout,
           objStyleFn, processor,
           triggerCallbackNow, callbackFn;
 
@@ -639,9 +641,11 @@
           obj.$el[ objStyleFn ]( obj.style, animOpts );
         };
         
-      } else if ( callback ) {
+      } else if ( callback || onLayout || animOpts.complete ) {
         // has callback
         var isCallbackTriggered = false,
+            // array of possible callbacks to trigger
+            callbacks = [ callback, onLayout, animOpts.complete ],
             instance = this;
         triggerCallbackNow = true;
         // trigger callback only once
@@ -649,7 +653,13 @@
           if ( isCallbackTriggered ) {
             return;
           }
-          callback.call( instance.element, $elems );
+          var hollaback;
+          for (var i=0, len = callbacks.length; i < len; i++) {
+            hollaback = callbacks[i];
+            if ( typeof hollaback === 'function' ) {
+              hollaback.call( instance.element, $elems );
+            }
+          }
           isCallbackTriggered = true;
         };
         
